summaryrefslogtreecommitdiff
path: root/python/__init__.py
diff options
context:
space:
mode:
Diffstat (limited to 'python/__init__.py')
-rw-r--r--python/__init__.py4
1 files changed, 3 insertions, 1 deletions
diff --git a/python/__init__.py b/python/__init__.py
index f9f8b2cb..9133fbe4 100644
--- a/python/__init__.py
+++ b/python/__init__.py
@@ -397,7 +397,7 @@ def load(*args, **kwargs) -> BinaryView:
:param Union[str, bytes, bytearray, 'databuffer.DataBuffer', 'os.PathLike'] source: a file or byte stream to load into a virtual memory space
:param bool update_analysis: whether or not to run :func:`update_analysis_and_wait` after opening a :py:class:`BinaryView`, defaults to ``True``
:param callback progress_func: optional function to be called with the current progress and total count
:param dict options: a dictionary in the form {setting identifier string : object value}
:return: returns a :py:class:`BinaryView` object for the given filename
:rtype: :py:class:`BinaryView`
@@ -405,6 +405,8 @@ def load(*args, **kwargs) -> BinaryView:
.. note:: The progress_func callback **must** return True to continue the load operation, False will abort the load operation.
+ .. warning:: The progress_func will **only** be called for BNDB files, not for any other file format due to a `design limitation <https://docs.binary.ninja/guide/debugger/index.html#navigating-the-binary>`_.
+
:Example:
>>> from binaryninja import *
>>> with load("/bin/ls") as bv:
@@ -397,7 +397,7 @@ def load(*args, **kwargs) -> BinaryView:
:param Union[str, bytes, bytearray, 'databuffer.DataBuffer', 'os.PathLike'] source: a file or byte stream to load into a virtual memory space
:param bool update_analysis: whether or not to run :func:`update_analysis_and_wait` after opening a :py:class:`BinaryView`, defaults to ``True``
- :param callback progress_func: optional function to be called with the current progress and total count
+ :param callback progress_func: optional function to be called with the current progress and total count for BNDB files only
:param dict options: a dictionary in the form {setting identifier string : object value}
:return: returns a :py:class:`BinaryView` object for the given filename